<?php

// $Id: $
/**
 * Form builder; Build the User Warn settings form.
 */
function search_api_facets_paths_settings_form($form, &$form_state) {

  $form['search_api_facets_paths'] = array(
    '#type' => 'fieldset',
    '#collapsible' => FALSE,
    '#tree' => TRUE,
    '#title' => t('Contexts'),
    '#description' => t('Ideally, this would describe in great detail how this
      configuration page works. The idea of facets paths started in <a href="@url">
      this Drupal.org discussion thread</a>.', array("@url" => url("http://drupal.org/node/1025402"))),
  );
  $contexts = variable_get('search_api_facets_paths', array());
  $pathtypes = module_invoke_all('search_api_facets_paths_pathtypes');
  $contexts[] = array('path' => '', 'pathtype' => '');
  foreach($contexts as $idx => $context) {
    $form['search_api_facets_paths'][$idx] = array(
      '#type' => 'fieldset',
      '#title' => t('Context #@idx', array('@idx' => $idx))
    );
    $form['search_api_facets_paths'][$idx]['path'] = array(
      '#type' => 'textfield',
      '#title' => t('Path'),
      '#default_value' => $context['path'],
      '#description' => 'The path (usually the base path of a view) where the
        path rewriting will take place. Leave empty to delete.',
    );
    $form['search_api_facets_paths'][$idx]['pathtype'] = array(
      '#type' => 'select',
      '#title' => 'Pathtype',
      '#default_value' => $context['pathtype'],
      '#options' => $pathtypes,
      '#description' => t('The way paths are being rewritten. For instance,
        <em>vocabulary-name/term-name</em> means that vocabulary and term names
        will be converted to lower case and spaces replaced with hyphens.<br />
        Multiple facets will be connected with forward slashes.<br />
        Other modules may implement their own pathtypes. In order to be
        available to the user here they need to implement <em>hook_search_api_facets_paths_pathtypes</em>.'),
    );
  }
  $form['#submit'][] = 'search_api_facets_paths_settings_form_submit';
  return system_settings_form($form);
}
function search_api_facets_paths_settings_form_submit($form, &$form_state) {
  foreach($form_state['values']['search_api_facets_paths'] as $key => $v) {
    $path = trim($v['path']);
    if (strlen($path) == 0 ) {
      unset($form_state['values']['search_api_facets_paths'][$key]);
    }
  }
}
/**
 * @addtogroup hooks
 * @{
 */

/**
 * return one or more path creation and parsing methods that can be used by
 * search_api_facets_paths to create a user friendly path instead of a
 * fragment
 *
 * The hook returns an array of this format:
 * "module_name_pathmaker_base" => t("Description of the pathmaker")
 *
 * Your module can implement the following functions:
 * module_name_pathmaker_base_make_path($vid, $names)
 *   take $vid, $names (array of taxonomy term names) and transform it into a
 *   (path) string that can be transformed back by _split_path() and _parse_path()
 * @see search_api_facets_paths_voc_slash_name_make_path
 * @see search_api_facets_paths_id_name_make_path
 * @see search_api_facets_paths_make_path
 *
 *
 * module_name_pathmaker_base_split_path($path)
 *   this function should split the path in a way that can be iterrated over
 *   by _parse_path(), return an array
 * @see search_api_facets_paths_split_path
 * @see search_api_facets_paths_voc_slash_name_split_path
 * @see search_api_facets_paths_id_name_split_path
 *
 * module_name_pathmaker_base_parse_path($path)
 *   convert back one part of the path (e.g. "type/briefing" - vocabulary name/
 *   term name) to vid, names
 * @see search_api_facets_paths_parse_path
 * @see search_api_facets_paths_voc_slash_name_parse_path
 * @see search_api_facets_paths_id_name_parse_path
 *
 * These three functions form a workflow in which _make_path() creates a string
 * that can be split (_split_path()) and transformed back into the original
 * vid and names array passed to _make_path().
 *
 * A simple but less useful implementation is the search_api_facets_paths_id_name
 * triple of functions.
 *
 * @see search_api_facets_paths_search_api_facets_paths_pathtypes
**/
function hook_search_api_facets_paths_pathtypes() {
  return array();
}
/**
 * @} End of "addtogroup hooks".
 */


/** Implements hook_search_api_facets_paths_pathtypes **/

function search_api_facets_paths_search_api_facets_paths_pathtypes() {
  return array(
    "search_api_facets_paths_voc_slash_name" => t("vocabulary-name/term-name"),
    "search_api_facets_paths_id_name" => t("vid-term-name (vocabulary ID, name)"),
  );
}